@@ -25,7 +25,7 @@ import argcomplete
 from matrixctl import __version__
 from .config_handler import Config
 from .api_handler import Api
-from .housekeeping import maintainance
+from .housekeeping import maintainance, restart, check
 from .updating import update
 from .account import adduser, deluser, list_users, adduser_jitsi, deluser_jitsi
 from .provisioning import deploy
@@ -66,6 +66,12 @@ def main():
     )
     adduser_parser.set_defaults(func=adduser)
 
+    ##########################################################################
+    # deluser
+    deluser_parser = subparsers.add_parser("deluser", help="Deletes a user")
+    deluser_parser.add_argument("user", help="The username to delete")
+    deluser_parser.set_defaults(func=deluser)
+
     ##########################################################################
     # adduser-jitsi
     adduser_jitsi_parser = subparsers.add_parser(
@@ -83,7 +89,7 @@ def main():
     adduser_jitsi_parser.set_defaults(func=adduser_jitsi)
 
     ##########################################################################
-    # deluser
+    # deluser-jitsi
     deluser_jitsi_parser = subparsers.add_parser(
         "deluser-jitsi", help="Deletes a jitsi user"
     )
@@ -104,10 +110,11 @@ def main():
     list_users_parser.set_defaults(func=list_users)
 
     ##########################################################################
-    # deluser
-    deluser_parser = subparsers.add_parser("deluser", help="Deletes a user")
-    deluser_parser.add_argument("user", help="The username to delete")
-    deluser_parser.set_defaults(func=deluser)
+    # update
+    update_parser = subparsers.add_parser(
+        "update", help="Updates the ansible repo"
+    )
+    update_parser.set_defaults(func=update)
 
     ##########################################################################
     # deploy
@@ -117,19 +124,35 @@ def main():
     deploy_parser.set_defaults(func=deploy)
 
     ##########################################################################
-    # deploy
-    update_parser = subparsers.add_parser(
-        "update", help="Updates the ansible repo"
+    # start
+    start_parser = subparsers.add_parser(
+        "start", help="Starts all OCI containers"
     )
-    update_parser.set_defaults(func=update)
+    start_parser.set_defaults(func=restart)  # Keep it "restart"
+
+    ##########################################################################
+    # restart
+    restart_parser = subparsers.add_parser(
+        "restart", help="Restarts all OCI containers (alias for start)"
+    )
+    restart_parser.set_defaults(func=restart)
 
     ##########################################################################
     # maintainance
     maintainance_parser = subparsers.add_parser(
-        "maintainance", help="Run Maintainance tasks"
+        "maintainance", help="Run maintainance tasks"
     )
     maintainance_parser.set_defaults(func=maintainance)
 
+    ##########################################################################
+    # check
+    check_parser = subparsers.add_parser(
+        "check", help="Checks the OCI containers"
+    )
+    check_parser.set_defaults(func=check)
+
+    ##########################################################################
+    # Parsing
     argcomplete.autocomplete(parser)
     args = parser.parse_args()
 
